@@ -64,7 +64,6 @@ class RedisLock(locking.Lock):
                                          thread_local=False)
         self._coord = coord
         self._client = client
-        self.acquired = False
 
     def is_still_owner(self):
         with _translate_failures():
@@ -74,14 +73,18 @@ class RedisLock(locking.Lock):
             owner_tok = self._client.get(self.name)
             return owner_tok == lock_tok
 
+    def break_(self):
+        with _translate_failures():
+            return bool(self._client.delete(self.name))
+
     def acquire(self, blocking=True):
         blocking, timeout = utils.convert_blocking(blocking)
         with _translate_failures():
-            self.acquired = self._lock.acquire(
+            acquired = self._lock.acquire(
                 blocking=blocking, blocking_timeout=timeout)
-            if self.acquired:
+            if acquired:
                 self._coord._acquired_locks.add(self)
-            return self.acquired
+            return acquired
 
     def release(self):
         if not self.acquired:
@@ -92,7 +95,6 @@ class RedisLock(locking.Lock):
             except exceptions.LockError:
                 return False
             self._coord._acquired_locks.discard(self)
-            self.acquired = False
             return True
 
     def heartbeat(self):
@@ -100,6 +102,10 @@ class RedisLock(locking.Lock):
             with _translate_failures():
                 self._lock.extend(self._lock.timeout)
 
+    @property
+    def acquired(self):
+        return self in self._coord._acquired_locks
+
 
 class RedisDriver(coordination._RunWatchersMixin,
                   coordination.CoordinationDriver):
